Developer's Guide
=================

Contributions
-------------

Currently there are no external contributors to this project. 
If that changes, further contribution guidelines will be updated.
If you're interested in contributing, please reach out.

Updating and Versioning
-----------------------

mymesh utilizes the semantic versioning (`"SemVer" <https://semver.org/>`_) scheme, where version numbers are formatted as "MAJOR.MINOR.PATCH".
Commits follow the `"Conventional Commits" <https://www.conventionalcommits.org>`_ scheme to support changelog generation via `commitizen <https://commitizen-tools.github.io/commitizen/>`_.